/**
  *  \file client/cm-marker.h
  *  \brief Chart Modes dealing with Drawings
  *
  *  (c) 2001-2013 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_CM_MARKER_H
#define PCC_V2_CLIENT_CM_MARKER_H

#include "game/drawing.h"
#include "client/chartmode.h"

/** Base class for drawing manipulation chart modes. Holds a reference
    to a drawing to manipulate, a basic event handler, and constructor
    fucntions for the derived-class modes. */
class WMarkerChartMode : public WSimpleChartMode {
 protected:
    GDrawingContainer::iterator drawing;

 public:
    WMarkerChartMode(GDrawingContainer::iterator drawing);
    ~WMarkerChartMode();
    bool handleEvent(const UIEvent& event, GChartLocation& loc);

    static void moveMarker(WChartModeList& modes, GDrawingContainer::iterator p);
    static void drawLineRectangle(WChartModeList& modes, GDrawingContainer::iterator p);
    static void drawCircle(WChartModeList& modes, GDrawingContainer::iterator p);
    static void deleteDrawing(WChartModeList& modes, GDrawingContainer::iterator p);
};

/** Chart mode for moving a marker. Moves a lockable marker
    (MarkerDrawing) around. */
class WMoveMarkerChartMode : public WMarkerChartMode {
 public:
    WMoveMarkerChartMode(GDrawingContainer::iterator p);

    void onMove(GChartLocation& loc);
    void drawOverlays(GfxCanvas& can, GChartLocation& loc);
    bool handleEvent(const UIEvent& event, GChartLocation& loc);
};

/** Chart mode for drawing a line or rectangle. Moves the second end
    of the object around. */
class WDrawMarkerChartMode : public WMarkerChartMode {
    void finishDrawing();
 public:
    WDrawMarkerChartMode(GDrawingContainer::iterator p);
    ~WDrawMarkerChartMode();

    void onMove(GChartLocation& loc);
    void drawOverlays(GfxCanvas& can, GChartLocation& loc);
    bool handleEvent(const UIEvent& event, GChartLocation& loc);
};

/** Chart mode for drawing a circle. Allows the user to manipulate the
    radius. */
class WDrawCircleChartMode : public WMarkerChartMode {
    void setRadius(int n);
 public:
    WDrawCircleChartMode(GDrawingContainer::iterator p);
    ~WDrawCircleChartMode();

    void onMove(GChartLocation& loc);
    void drawOverlays(GfxCanvas& can, GChartLocation& loc);
    bool handleEvent(const UIEvent& event, GChartLocation& loc);
};

/** Chart mode for deleting a drawing. Blinks the drawing and aske the
    user for delete permission. */
class WDeleteDrawingChartMode : public WMarkerChartMode {
    int counter;
    bool phase;
 public:
    WDeleteDrawingChartMode(GDrawingContainer::iterator p);
    ~WDeleteDrawingChartMode();

    void drawCursor(GfxCanvas& can, GChartLocation& loc);
    void drawOverlays(GfxCanvas& can, GChartLocation& loc);
    bool handleEvent(const UIEvent& event, GChartLocation& loc);
};

void editMarkerComment(GDrawing& marker);

#endif
