/**
  *  \file client/scr-ufo.cc
  *
  *  (c) 2001-2013 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/screens.h"
#include "game/global.h"
#include "util/nls.h"
#include "ui/layout.h"
#include "gfx/palette.h"
#include "game/formula.h"
#include "cpluslib/format.h"
#include "ui/util.h"
#include "client/tiles/objheader.h"
#include "client/tiles/ufoinfo.h"
#include "int/if/userif.h"
#include "client/widgets/objcontrol.h"
#include "ui/widgets/button.h"
#include "ui/window.h"
#include "ui/uiglobal.h"
#include "client/tiles/ufosettings.h"

namespace {
    class WUfoInfoWindow : public UIWindow {
        ObjectHolder h;
        GObjectSelection& selection;
        void init();
     public:
        WUfoInfoWindow(GObjectSelection& selection);
    };
}

/***************************** WUfoInfoWindow ****************************/

WUfoInfoWindow::WUfoInfoWindow(GObjectSelection& selection)
    : UIWindow(_("Ufo Information"), BLUE_WINDOW, COLOR_GRAY),
      selection(selection)
{
    init();
}

void
WUfoInfoWindow::init()
{
    setLayout(UIVBoxLayout::instance5);

    UIGroup& g1 = h.add(new UIGroup(UIHBoxLayout::instance5));

    g1.add(h.add(new UIButton(0, _("Close"), SDLK_ESCAPE)).addStop());
    g1.add(h.add(new UIButton(1, _("Go To"), SDLK_RETURN)).addStop());
    g1.add(h.add(new UISpacer()));

    add(h.add(new WObjectSelectionHeaderTile(selection)));
    add(h.add(new WUfoInfoTile(selection)));
    add(h.add(new WUfoSettingsTile(selection)));
    add(g1);
    add(h.add(new WObjectSelectionControl(selection)));

    pack();
}


void
doUfoScreen()
{
    if (current_ufo_type.isEmpty())
        return;

    WUfoInfoWindow win(current_ufo_selection);
    ui_root->centerWidget(win);
    int result = ui_root->runModal(win);
    if (result == 1) {
        // "Go to"
        if (GMapObject* mo = dynamic_cast<GMapObject*>(current_ufo_selection.getCurrentObject())) {
            IntUserInterfaceBinding::getCurrentInstance()->doGoToChart(mo->getPos());
        }
    }
}
