/**
  *  \file client/tiles/shipoverview.cc
  *
  *  (c) 2001-2013 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/tiles/shipoverview.h"
#include "cpluslib/format.h"
#include "game/formula.h"
#include "game/ship.h"
#include "game/univ.h"
#include "ui/uiglobal.h"
#include "util/nls.h"

/*************************** WShipOverviewTile **************************/

WShipOverviewTile::WShipOverviewTile(GObjectSelection& selection)
    : WObjectSelectionObserverTile(font_sizes[FONT_NORMAL_BOLD].scaledBy(30, 10), selection)
{ }

WShipOverviewTile::~WShipOverviewTile()
{ }

void
WShipOverviewTile::drawData(GfxCanvas& can)
{
    GShip* sh = dynamic_cast<GShip*>(getCurrentObject());
    if (!sh)
        return;

    GUniverse* univ = getCurrentUniverse();
    if (!univ)
        return;

    GShip& ps = *sh;

    GfxContext ctx;
    ctx.useCanvas(can);
    ctx.useColorScheme(getSkin());
    ctx.useFont(*fonts[FONT_NORMAL]);
    ctx.setSolidBackground();

    // FIXME: this is very incomplet
    int y = 0, x = 0;
    int w = getInnerSize(0, 0).w;

    outTextF(ctx, x, y, w, ps.getHull().getName());
    y += font_heights[FONT_NORMAL];
    outTextF(ctx, x, y, w,
             _("Location: ") + univ->getLocationName(ps.getPos(), locs_WW | locs_Orbit | locs_Verbose));
    y += font_heights[FONT_NORMAL];
    outTextF(ctx, x, y, w,
             _("Waypoint: ") + univ->getLocationName(ps.getWaypoint(), locs_WW | locs_Verbose));
    y += font_heights[FONT_NORMAL];
    outTextF(ctx, x, y, w,
             format(_("Distance: %.2f ly"), distFromDX(ps.getWaypointDX(),
                                                       ps.getWaypointDY())));
}
