/**
  *  \file client/widgets/configview.cc
  *
  *  (c) 2001-2013 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/widgets/configview.h"
#include "cpluslib/format.h"

static bool
SortOptionByName(ConfigOption* a, ConfigOption* b)
{
    return strCaseCmp(a->getName(), b->getName()) < 0;
}


WConfigView::WConfigView(int id, int nlines, int width)
    : UIListbox(id, nlines, width, 0),
      data(),
      level(ConfigOption::srcGame),
      nameColumnWidth(20)
{ }

WConfigView::~WConfigView()
{ }

void
WConfigView::setHighlightSource(ConfigOption::Source level)
{
    this->level = level;
    drawWidget();
}

void
WConfigView::setNameColumnWidth(int widthInEms)
{
    this->nameColumnWidth = widthInEms;
    drawWidget();
}


    
void
WConfigView::setContent(Config& cfg)
{
    setContent(cfg, string_t());
}

void
WConfigView::setContent(Config& cfg, string_t filter)
{
    ConfigOption* current = getCurrentOption();

    data.clear();
    for (Config::iterator i = cfg.begin(); i != cfg.end(); ++i) {
        if (filter.empty() || strUCase(i->getName()).find(strUCase(filter)) != string_t::npos) {
            data.push_back(&*i);
        }
    }
    sort(data.begin(), data.end(), SortOptionByName);

    int index = 0;
    if (current != 0) {
        std::vector<ConfigOption*>::const_iterator it = find(data.begin(), data.end(), current);
        if (it != data.end()) {
            index = it - data.begin();
        }
    }
    setSize(data.size());
    scrollTo(index, 1);
    adjustPosition();
    drawWidget();
}

void
WConfigView::drawPart(GfxCanvas& can, int from, int to)
{
    GfxContext ctx;
    ctx.useCanvas(can);
    ctx.useColorScheme(getSkin());
    for (int i = from; i < to; ++i) {
        GfxRect r;
        prepareEntry(ctx, ColorStyle, i, &r);

        int index = i + getTop();
        if (index < int(data.size())) {
            ConfigOption* opt = data[index];
            if (opt->getSource() > level) {
                ctx.useFont(*fonts[FONT_NORMAL_BOLD]);
            } else {
                ctx.useFont(*fonts[FONT_NORMAL]);
            }
            r.consumeX(10);
            outTextF(ctx, r.splitX(nameColumnWidth*font_ems[FONT_NORMAL]), opt->getName());
            outTextF(ctx, r, opt->toString());
        }
    }
}

ConfigOption*
WConfigView::getCurrentOption()
{
    int n = getCurrent();
    if (n < int(data.size())) {
        return data[n];
    } else {
        return 0;
    }
}
